api

package
v0.0.0-...-eef4e93 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 9, 2020 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package api is the package of the Turdus API interface

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Start

func Start()

Start is the function responsible to start and setup the Turdus API

Types

This section is empty.

Directories

Path Synopsis
Package healthcheck is the package of the healthcheck API route
Package healthcheck is the package of the healthcheck API route
Package tweet is related with get tweets route
Package tweet is related with get tweets route

Jump to