package
Version:
v0.0.0-...-eef4e93
Opens a new window with list of versions in this module.
Published: Dec 9, 2020
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package tweet is related with get tweets route
type Request struct {
Author string `json:"author"`
DateFrom string `json:"dateFrom"`
DateTo string `json:"dateTo"`
}
Request represents the tweets route default request
type Response struct {
Results []service.Tweet `json:"tweets"`
}
Response represents the tweet route response
Source Files
¶
Click to show internal directories.
Click to hide internal directories.